@@ -185,7 +185,19 @@ static struct {
   ERR (GSASL_NO_SERVICE,
        N_("Authentication failed because the service name was not provided.")),
   ERR (GSASL_NO_HOSTNAME,
-       N_("Authentication failed because the host name was not provided."))
+       N_("Authentication failed because the host name was not provided.")),
+  ERR (GSASL_GSSAPI_ENCAPSULATE_TOKEN_ERROR,
+       N_("GSSAPI error encapsulating token.")),
+  ERR (GSASL_GSSAPI_DECAPSULATE_TOKEN_ERROR,
+       N_("GSSAPI error decapsulating token.")),
+  ERR (GSASL_GSSAPI_INQUIRE_MECH_FOR_SASLNAME_ERROR,
+       N_("GSSAPI error getting OID for SASL mechanism name.")),
+  ERR (GSASL_GSSAPI_TEST_OID_SET_MEMBER_ERROR,
+       N_("GSSAPI error testing for OID in OID set.")),
+  ERR (GSASL_GSSAPI_RELEASE_OID_SET_ERROR,
+       N_("GSSAPI error releasing OID set.")),
+  ERR (GSASL_NO_CB_TLS_UNIQUE,
+       N_("Authentication failed because a tls-unique CB was not provided."))
 };
 
 /**
